CCL: ccl_cosmology Struct Reference

CCL

Data Fields
ccl_cosmology Struct Reference

`#include <ccl_core.h>`

## Data Fields
ccl_parameters | params
ccl_configuration | config
ccl_data | data
bool | computed_distances
bool | computed_growth
bool | computed_power
bool | computed_sigma
bool | computed_hmfparams
int | status
char | status_message [500]

## Detailed Description

Sturct containing references to instances of the above structs, and boolean flags of precomputed values.

## Field Documentation

## ◆ computed_distances

bool ccl_cosmology::computed_distances

## ◆ computed_growth

bool ccl_cosmology::computed_growth

## ◆ computed_hmfparams

bool ccl_cosmology::computed_hmfparams

## ◆ computed_power

bool ccl_cosmology::computed_power

## ◆ computed_sigma

bool ccl_cosmology::computed_sigma

## ◆ config

ccl_configuration ccl_cosmology::config

## ◆ data

ccl_data ccl_cosmology::data

## ◆ params

ccl_parameters ccl_cosmology::params

## ◆ status

int ccl_cosmology::status

## ◆ status_message

char ccl_cosmology::status_message[500]

The documentation for this struct was generated from the following file:

- /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_core.h